==> af-common-task-1.1.16.17-sources.jar: com/af/v4/system/common/task/consumer/TaskManageHandler.java <==
package com.af.v4.system.common.task.consumer;

import com.af.v4.system.common.plugins.http.RestTools;
import com.af.v4.system.common.task.entity.Task;
import com.af.v4.system.common.task.entity.TaskHandler;
import com.af.v4.system.common.task.entity.vo.TaskResult;
import com.af.v4.system.common.task.enums.TaskStatus;
import com.af.v4.system.common.task.event.TaskEvent;
import com.af.v4.system.common.task.product.TaskProduct;
import com.lmax.disruptor.WorkHandler;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.config.ConfigurableBeanFactory;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import java.sql.Timestamp;
import java.util.HashMap;
import java.util.Map;

/**
 * 任务消息处理器
 * <p>
 * WorkHandler 处理重复消费
 */
@Component
@Scope(ConfigurableBeanFactory.SCOPE_PROTOTYPE)
public class TaskManageHandler implements WorkHandler<TaskEvent> {

    private final static Logger LOGGER = LoggerFactory.getLogger(TaskManageHandler.class);

    public final static String TASK_MANAGER_TABLE = "t_task_management";
    public final static String TASK_EXECUTE_LOG = "t_task_execute_log";
    public final static Map<Integer, Thread> threadMap = new HashMap<>();

    @Override
    public void onEvent(TaskEvent event) {

        TaskHandler taskHandler = event.getTemplateTaskHandler();
        Task task = event.getTemplateTask();
        LOGGER.info(">>>> 开始执行任务: " + task.getTaskName() + " - " + task.getTaskClass());

        String taskGetByIdRes = RestTools.post(TaskProduct.serverAddress + "/taskGetByQuery", new JSONObject()
                .put("query", "id = '" + task.getId() + "'"));
        JSONObject taskJson = new JSONObject(taskGetByIdRes).getJSONArray("data").getJSONObject(0);
        if (TaskStatus.INTERRUPT.getStatus().equals(taskJson.getString("f_task_status"))) {
            return;
        }
        Timestamp timestamp = new Timestamp(System.currentTimeMillis());
        task.setTaskStatus(TaskStatus.RUNNING.getStatus());
        task.setStartTime(timestamp);
        task.setProgress(0.0);

        RestTools.post(TaskProduct.serverAddress + "/taskSave", new JSONObject()
                .put(TaskManageHandler.TASK_MANAGER_TABLE, Task.convertToJson(task)));
        RestTools.post(TaskProduct.serverAddress + "/taskExecuteSave", new JSONObject()
                .put(TaskManageHandler.TASK_EXECUTE_LOG, new JSONObject()
                        .put("f_task_id", task.getId())
                        .put("f_time", timestamp)
                        .put("f_progress", 0.0)
                        .put("f_task_status", task.getTaskStatus())));

        try {
            threadMap.put(task.getId(), Thread.currentThread());
            TaskResult<String> res = taskHandler.run(task);
            task.setTaskStatus(res.getMsg().getStatus());
            task.setResult(res.getData().toString());
        } catch (Exception e) {
            task.setTaskStatus(TaskStatus.INTERRUPT.getStatus());
            e.printStackTrace();
        } finally {
            LOGGER.info(">>>> " + task.getId() + "执行结束, 执行结果: " + task.getTaskStatus());
            TaskProduct.taskIdRinBufferSequence.remove(task.getId());
            threadMap.remove(task.getId());

            Timestamp endTime = new Timestamp(System.currentTimeMillis());
            task.setEndTime(endTime);
            task.setProgress(1.0);
            RestTools.post(TaskProduct.serverAddress + "/taskSave", new JSONObject()
                    .put(TaskManageHandler.TASK_MANAGER_TABLE, Task.convertToJson(task)));
            RestTools.post(TaskProduct.serverAddress + "/taskExecuteSave", new JSONObject()
                    .put(TaskManageHandler.TASK_EXECUTE_LOG, new JSONObject()
                            .put("f_task_id", task.getId())
                            .put("f_time", timestamp)
                            .put("f_task_status", task.getTaskStatus())));
        }

    }
}

==> af-common-task-1.1.16.47-sources.jar: com/af/v4/system/common/task/consumer/TaskManageHandler.java <==
package com.af.v4.system.common.task.consumer;

import com.af.v4.system.common.logic.service.LogicService;
import com.af.v4.system.common.redis.RedisService;
import com.af.v4.system.common.task.entity.Task;
import com.af.v4.system.common.task.entity.TaskHandler;
import com.af.v4.system.common.task.entity.vo.TaskResult;
import com.af.v4.system.common.task.enums.TaskStatus;
import com.af.v4.system.common.task.event.TaskEvent;
import com.af.v4.system.common.task.product.TaskProduct;
import com.lmax.disruptor.WorkHandler;
import org.json.JSONArray;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.config.ConfigurableBeanFactory;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import java.sql.Timestamp;
import java.util.HashMap;
import java.util.Map;

/**
 * 任务消息处理器
 * <p>
 * WorkHandler 处理重复消费
 */
@Component
@Scope(ConfigurableBeanFactory.SCOPE_PROTOTYPE)
public class TaskManageHandler implements WorkHandler<TaskEvent> {

    private final static Logger LOGGER = LoggerFactory.getLogger(TaskManageHandler.class);

    public final static String TASK_MANAGER_TABLE = "t_task_management";
    public final static String TASK_EXECUTE_LOG = "t_task_execute_log";
    public final static Map<Integer, Thread> threadMap = new HashMap<>();

    @Autowired
    private RedisService redisService;
    @Autowired
    private LogicService logicService;

    @Override
    public void onEvent(TaskEvent event) {

        TaskHandler taskHandler = event.getTemplateTaskHandler();
        Task task = event.getTemplateTask();
        LOGGER.info(">>>> 任务消费开始: " + task.getTaskName());

        JSONObject taskJson = ((JSONArray) logicService.run("taskGetByQuery", String.valueOf(new JSONObject()
                .put("query", "id = '" + task.getId() + "'")))).getJSONObject(0);
        if (TaskStatus.INTERRUPT.getStatus().equals(taskJson.getString("f_task_status"))) {
            return;
        }
        Timestamp timestamp = new Timestamp(System.currentTimeMillis());
        task.setTaskStatus(TaskStatus.RUNNING.getStatus());
        task.setStartTime(timestamp);
        task.setProgress(0.0);

        logicService.run("taskSave", Task.convertToJson(task));

        try {
            threadMap.put(task.getId(), Thread.currentThread());
            // 消费时, redis中不存在此任务, 返回失败
            if (!redisService.hasKey("TASK-" + task.getId() + "-param")) {
                task.setTaskStatus(TaskStatus.FAILED.getStatus());
                task.setResult("任务丢失");
                throw new RuntimeException();
            } else {
                String param = redisService.get("TASK-" + task.getId() + "-param");
                task.setParam(param);
                redisService.delete("TASK-" + task.getId() + "-param");
            }
            TaskResult<String> res = taskHandler.run(task, taskHandler);
            task.setTaskStatus(res.getMsg().getStatus());
            task.setResult(res.getData().toString());
        } catch (Exception e) {
            LOGGER.info(">>>> 任务消费异常" + task.getTaskName());
            task.setTaskStatus(TaskStatus.FAILED.getStatus());
            e.printStackTrace();
        } finally {
            task.setParam(null);
            TaskProduct.taskIdRinBufferSequence.remove(task.getId());
            threadMap.remove(task.getId());

            Timestamp endTime = new Timestamp(System.currentTimeMillis());
            task.setEndTime(endTime);
            task.setProgress(1.0);
            logicService.run("taskSave", Task.convertToJson(task));
            LOGGER.info(">>>> 任务消费结束: " + task.getTaskName());
        }

    }
}
